@@ -26,6 +26,7 @@ from .utils import (
     mem,
     trajectories,
     transformations,
+    visual,
 )
 from .utils.trajectories import read_csv
-from .visualization import visualization
+from .visualization import folium, matplotlib
