@@ -1,10 +1,13 @@
 import numpy as np
 from sklearn.cluster import KMeans
 
-from pymove.utils.log import progress_bar
+from pymove.utils.log import progress_bar, timer_decorator
 
 
-def elbow_method(move_data, k_initial=1, max_clusters=15, k_iteration=1):
+@timer_decorator
+def elbow_method(
+        move_data, k_initial=1, max_clusters=15, k_iteration=1, random_state=None
+):
     """
     Determines the optimal number of clusters in the range set by the user using
     the elbow method.
@@ -21,6 +24,9 @@ def elbow_method(move_data, k_initial=1, max_clusters=15, k_iteration=1):
         Maximum number of clusters to test for
     k_iteration: int, optional (1 by default).
         Increment value of the sequence used by the elbow method.
+    random_state: int, RandomState instance, default=None
+        Determines random number generation for centroid initialization.
+        Use an int to make the randomness deterministic
 
     Returns
     -------
@@ -40,17 +46,19 @@ def elbow_method(move_data, k_initial=1, max_clusters=15, k_iteration=1):
 
     """
 
-    message = 'Executing Elbow Method to:\n...K of %s to %s from k_iteration:%s\n'
+    message = 'Executing Elbow Method to:\n...K of %srs to %srs from k_iteration:%srs\n'
     message = message % (k_initial, max_clusters, k_iteration)
     print(message, flush=True)
     inertia_dic = {}
     for k in progress_bar(range(k_initial, max_clusters + 1, k_iteration)):
-        inertia_dic[k] = KMeans(n_clusters=k).fit(move_data).inertia_
+        km = KMeans(n_clusters=k, random_state=random_state)
+        inertia_dic[k] = km.fit(move_data).inertia_
     return inertia_dic
 
 
+@timer_decorator
 def gap_statistic(
-    move_data, nrefs=3, k_initial=1, max_clusters=15, k_iteration=1
+    move_data, nrefs=3, k_initial=1, max_clusters=15, k_iteration=1, random_state=None
 ):
     """
     Calculates optimal clusters numbers using Gap Statistic from Tibshirani,
@@ -69,6 +77,9 @@ def gap_statistic(
         Maximum number of clusters to test for.
     k_iteration:int, optional (1 by default).
         Increment value of the sequence used by the elbow method.
+    random_state: int, RandomState instance, default=None
+        Determines random number generation for centroid initialization.
+        Use an int to make the randomness deterministic
 
     Returns
     -------
@@ -81,10 +92,11 @@ def gap_statistic(
 
     """
 
-    message = 'Executing Gap Statistic to:\n...K of %s to %s from k_iteration:%s\n'
+    message = 'Executing Gap Statistic to:\n...K of %srs to %srs from k_iteration:%srs\n'
     message = message % (k_initial, max_clusters, k_iteration)
     print(message, flush=True)
     gaps = {}
+    np.random.seed(random_state)
     for k in progress_bar(range(k_initial, max_clusters + 1, k_iteration)):
         # Holder for reference dispersion results
         ref_disps = np.zeros(nrefs)
@@ -94,15 +106,14 @@ def gap_statistic(
             # Create new random reference set
             random_reference = np.random.random_sample(size=move_data.shape)
             # Fit to it
-            km = KMeans(k)
-            km.fit(random_reference)
-            ref_disps[i] = km.inertia_
+            km = KMeans(n_clusters=k, random_state=random_state)
+            ref_disps[i] = km.fit(random_reference).inertia_
         # Fit cluster to original data and create dispersion
         km = KMeans(k).fit(move_data)
         orig_disp = km.inertia_
         # Calculate gap statistic
         gap = np.log(np.mean(ref_disps)) - np.log(orig_disp)
-        # Assign this loop's gap statistic to gaps
+        # Assign this loop'srs gap statistic to gaps
         gaps[k] = gap
 
     return gaps
