@@ -1,5 +1,3 @@
-import time
-
 import numpy as np
 
 from pymove.preprocessing.segmentation import by_max_dist
@@ -15,9 +13,10 @@ from pymove.utils.constants import (
     TIME_TO_PREV,
     TRAJ_ID,
 )
+from pymove.utils.log import timer_decorator
 
 
-def create_update_datetime_in_format_cyclical(
+def create_or_update_datetime_in_format_cyclical(
     move_data, label_datetime=DATETIME, inplace=True
 ):
     """
@@ -66,6 +65,7 @@ def create_update_datetime_in_format_cyclical(
         raise e
 
 
+@timer_decorator
 def create_or_update_move_stop_by_dist_time(
         move_data,
         dist_radius=30,
@@ -91,7 +91,7 @@ def create_or_update_move_stop_by_dist_time(
         If the user stayed in the segment for a time
         greater than time_radius, than the segment is a stop.
     label_id : str, optional, default 'id'
-         Indicates the label of the id column in the user"s dataframe.
+         Indicates the label of the id column in the user"srs dataframe.
     new_label : float, optional, default 'segment_stop'
         Is the name of the column to indicates if a point is a stop of a move.
     inplace : boolean, optional, default True
@@ -108,7 +108,6 @@ def create_or_update_move_stop_by_dist_time(
     """
 
     try:
-        start_time = time.time()
 
         if not inplace:
             move_df = move_data[:]
@@ -143,11 +142,6 @@ def create_or_update_move_stop_by_dist_time(
         ].index
         move_df.at[idx, STOP] = True
         print(move_df[STOP].value_counts())
-        print(
-            '\nTotal Time: %.2f seconds'
-            % (time.time() - start_time)
-        )
-        print('-----------------------------------------------------\n')
 
         if not inplace:
             return move_df
@@ -155,7 +149,8 @@ def create_or_update_move_stop_by_dist_time(
         raise e
 
 
-def create_update_move_and_stop_by_radius(
+@timer_decorator
+def create_or_update_move_and_stop_by_radius(
     move_data,
     radius=0,
     target_label=DIST_TO_PREV,
@@ -173,7 +168,7 @@ def create_update_move_and_stop_by_radius(
     radius :  Double, optional(900 by default)
         The radius value is used to determine if a segment is a stop.
         If the value of the point in target_label is
-        greater than radius, the segment is a stop, otherwise it's a move.
+        greater than radius, the segment is a stop, otherwise it'srs a move.
     target_label : String, optional(dist_to_prev by default)
         The feature used to calculate the stay points.
     new_label : String, optional(situation by default)
